@@ -634,7 +634,7 @@ class Report:
         overwrite : bool, default = False
             Set to true if overwriting the current classes.
         """
-        e = self._get_col_from_idx_arg(idx = col_idx, row_idx = row_idx, container_name = container_name)
+        e = self._get_col_from_idx_arg(col_idx = col_idx, row_idx = row_idx, container_name = container_name)
         e.add_cls(vals, overwrite)
 
     def set_col_sty(self, vals, col_idx = None, row_idx = None, container_name = None, overwrite = False):
@@ -654,7 +654,7 @@ class Report:
         overwrite : bool, default = False
             Set to true if overwriting the current styles.
         """
-        e = self._get_col_from_idx_arg(idx = col_idx, row_idx = row_idx, container_name = container_name)
+        e = self._get_col_from_idx_arg(col_idx = col_idx, row_idx = row_idx, container_name = container_name)
         e.add_sty(vals, overwrite)
 
     def add(self,
@@ -695,16 +695,16 @@ class Report:
 
         elements = as_list(elements)
         if new_row and not overwrite:
-            self.add_row(idx = row_idx, container_name = container_name, overwrite = False)
+            self.add_row(row_idx = row_idx, container_name = container_name, overwrite = False)
         if new_col and not overwrite:
-            self.add_col(idx = col_idx, row_idx = row_idx, container_name = container_name, overwrite = False)
+            self.add_col(col_idx = col_idx, row_idx = row_idx, container_name = container_name, overwrite = False)
         
         if overwrite:
             #First verify that the column we want to overwrite actually exists.
-            self._get_col_from_idx_arg(idx = col_idx, row_idx = row_idx, container_name = container_name)
-            self.add_col(idx = col_idx, row_idx = row_idx, container_name = container_name, overwrite = True)
+            self._get_col_from_idx_arg(col_idx = col_idx, row_idx = row_idx, container_name = container_name)
+            self.add_col(col_idx = col_idx, row_idx = row_idx, container_name = container_name, overwrite = True)
 
-        col = self._get_col_from_idx_arg(idx = col_idx, row_idx = row_idx, container_name = container_name)
+        col = self._get_col_from_idx_arg(col_idx = col_idx, row_idx = row_idx, container_name = container_name)
         if size is not None:
             col.size = size
         
@@ -785,4 +785,4 @@ class Report:
             
         filename = get_filename(filename, "pdf")
             
-        weasyprint.HTML(string=self.save_html()).write_pdf(filename)
\ No newline at end of file
+        weasyprint.HTML(string=self.save_html()).write_pdf(filename)
